pyxmpp.sasl.gssapi

Package pyxmpp :: Package sasl :: Module gssapi |
[hide private]

# Module gssapi

source code

GSSAPI authentication mechanism for PyXMPP SASL implementation.

Normative reference:
  - RFC 4752

Classes | [hide private]
| GSSAPIClientAuthenticator Provides client-side GSSAPI SASL (Kerberos 5) authentication.

Variables | [hide private]
| __revision__ = `"$Id$"`

Imports: base64, kerberos, logging, ClientAuthenticator, Failure, Response, Challenge, Success